// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_i18n/src/core/utils/parser.dart';
import 'package:wyatt_i18n/src/core/utils/parsers/json_parser.dart';

/// {@template arb_parser}
/// A class that parses a given input of type [String] into a given output
/// of type [Map<String, dynamic>].
/// {@endtemplate}
class ArbParser extends Parser<String, Map<String, dynamic>> {
  /// {@macro arb_parser}
  const ArbParser() : super();

  /// Parses the given [input] of type [String] into a given output of type
  /// [Map<String, dynamic>].
  ///
  /// ARB files are JSON files, so we can use the JSON parser.
  @override
  Map<String, dynamic> parse(String input) => const JsonParser().parse(input);
}
