// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// super program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// super program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with super program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

class NavigationItem extends StatelessWidget {
  const NavigationItem({
    required this.item,
    required this.selected,
    super.key,
  });
  final TextWrapper item;
  final bool selected;

  @override
  Widget build(BuildContext context) => Stack(
        alignment: Alignment.bottomCenter,
        children: [
          if (selected)
            Container(
              height: ThemeHelper.getThemeElement<double, double>(
                [
                  context
                      .themeExtension<TopBarThemeExtension>()
                      ?.selectedIndicatorHeight,
                  // TODO(wyatt): move default value
                  5,
                ],
                valueValidator: (value) => value != null,
                transform: (value) => value,
              ),
              width: ThemeHelper.getThemeElement<double, double>(
                [
                  context
                      .themeExtension<TopBarThemeExtension>()
                      ?.selectedIndicatorWidth,
                  // TODO(wyatt): move default value
                  70,
                ],
                valueValidator: (value) => value != null,
                transform: (value) => value,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(100),
                color: ThemeHelper.getThemeElement<Color, Color>(
                  [
                    context
                        .themeExtension<TopBarThemeExtension>()
                        ?.secondaryColor,
                    context.colorScheme.primary
                  ],
                  valueValidator: (value) => value != null,
                  transform: (value) => value,
                ),
              ),
            ),
          ConstrainedBox(
            constraints: BoxConstraints(
              minWidth: ThemeHelper.getThemeElement<double, double>(
                    [
                      context
                          .themeExtension<TopBarThemeExtension>()
                          ?.selectedIndicatorWidth,
                      // TODO(wyatt): move default value
                      70,
                    ],
                    valueValidator: (value) => value != null,
                    transform: (value) => value,
                  ) ??
                  double.infinity,
            ),
            child: SizedBox(
              height: 50,
              child: Center(
                child: Text(
                  item.data,
                  style: ThemeHelper.getThemeElement<TextStyle, TextStyle>(
                    [
                      context.textTheme.titleMedium,
                      context
                          .themeExtension<TopBarThemeExtension>()
                          ?.subTitleStyle,
                      item.style,
                    ],
                    combine: (value, element) => value?.merge(element),
                    valueValidator: (value) => value != null,
                    transform: (value) => value,
                  ),
                ),
              ),
            ),
          ),
        ],
      );
}
